@@ -99,12 +99,15 @@ class Menu_Manager(object):
             py.display.update()
 
     def Update(self):
-        if self.actual_menu:
-            if self.actual_menu.background == None:
-                self.screen.blit(self.background,(0,0))
-            else:
-                self.screen.blit(self.actual_menu.background,(0,0))
-            self.actual_menu.Update()
+        if self.running:
+            if self.actual_menu:
+                if self.actual_menu.background == None:
+                    self.screen.blit(self.background,(0,0))
+                else:
+                    self.screen.blit(self.actual_menu.background,(0,0))
+                self.actual_menu.Update()
+        else:
+            raise SystemExit
             
     def stop(self):
         """
@@ -336,6 +339,8 @@ class Button(sprite):
     def check_layer(self):
         for _sprite in _window.actual_menu.sprites:
             if _sprite.isactive:
+                if _sprite.rect == None:
+                    continue
                 if _sprite.rect.collidepoint(py.mouse.get_pos()) and _sprite.layer > self.layer:
                     return False
         else:
